@@ -154,7 +154,11 @@ void SessionThread::run()
             m_parentSession->d, &SessionPrivate::socketDisconnected);
     connect(m_socket.get(), &QSslSocket::connected,
             m_parentSession->d, &SessionPrivate::socketConnected);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(m_socket.get(), QOverload<QAbstractSocket::SocketError>::of(&QAbstractSocket::error),
+#else
+    connect(m_socket.get(), QOverload<QAbstractSocket::SocketError>::of(&QAbstractSocket::errorOccurred),
+#endif
             this, [this](QAbstractSocket::SocketError err) {
         qCWarning(KSMTP_LOG) << "SMTP Socket error:" << err << m_socket->errorString();
         Q_EMIT m_parentSession->connectionError(m_socket->errorString());
@@ -223,13 +227,23 @@ void SessionThread::sslConnected()
     QMutexLocker locker(&m_mutex);
     QSslCipher cipher = m_socket->sessionCipher();
 
-    if (!m_socket->sslErrors().isEmpty() || !m_socket->isEncrypted()
+#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
+    if (!m_socket->sslErrors().isEmpty()
+#else
+    if (!m_socket->sslHandshakeErrors().isEmpty()
+#endif
+        || !m_socket->isEncrypted()
         || cipher.isNull() || cipher.usedBits() == 0) {
         qCDebug(KSMTP_LOG) << "Initial SSL handshake failed. cipher.isNull() is" << cipher.isNull()
                            << ", cipher.usedBits() is" << cipher.usedBits()
                            << ", the socket says:" <<  m_socket->errorString()
                            << "and the list of SSL errors contains"
-                           << m_socket->sslErrors().count() << "items.";
+                      #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
+                           << m_socket->sslErrors().count()
+                      #else
+                           << m_socket->sslHandshakeErrors().count()
+                      #endif
+                           << "items.";
         KSslErrorUiData errorData(m_socket.get());
         Q_EMIT sslError(errorData);
     } else {
